// $Id: PktDagSrc.h 2703 2006-04-04 07:35:21Z vern $
//
// Copyright (c) 1999, 2000, 2001, 2002
//      The Regents of the University of California.  All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that: (1) source code distributions
// retain the above copyright notice and this paragraph in its entirety, (2)
// distributions including binary code include the above copyright notice and
// this paragraph in its entirety in the documentation or other materials
// provided with the distribution, and (3) all advertising materials mentioning
// features or use of this software display the following acknowledgement:
// ``This product includes software developed by the University of California,
// Lawrence Berkeley Laboratory and its contributors.'' Neither the name of
// the University nor the names of its contributors may be used to endorse
// or promote products derived from this software without specific prior
// written permission.
// THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
// WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
//
// Support for Endace's DAG interface card.
//
// Caveats:
//    - No support for hardware-side filtering yet.
//    - No support for secondary filter path yet.
//    - No support for other media than Ethernet.
//    - Mutex should be per interface
//    - No support for multiple rx streams

#ifndef PKTDAGSRC_H
#define PKTDAGSRC_H

#ifdef USE_DAG

extern int snaplen;

#include "PktSrc.h"

class PktDagSrc : public PktSrc {
public:
	PktDagSrc(const char* interface, const char* filter,
			PktSrc_Filter_Type ft = TYPE_FILTER_NORMAL);
	virtual ~PktDagSrc();

	// PktSrc interface:
	virtual void Statistics(Stats* stats);
	virtual int SetFilter(int index);
	virtual int SetNewFilter(const char* filter);

protected:
	virtual int ExtractNextPacket();
	virtual void GetFds(int* read, int* write, int* except);
	virtual void Close();

	void Error(const char* str);

	static const unsigned int EXTRA_WINDOW_SIZE = 4 * 1024 * 1024;
	static const int stream_num = 0;	// use receive stream 0

	// Unfortunaly the DAG API has some problems with locking streams,
	// so we do our own checks to ensure we don't use more than one
	// stream.   In particular, the secondary filter won't work.
	static int mutex;

	int fd;
	bpf_program* current_filter;
};
#endif

#endif
